@@ -2,6 +2,7 @@
 from abc import ABCMeta, abstractmethod
 from pydantic import BaseModel
 import sys
+import os
 sys.path.append("app/")
 import pymongo
 from pymongo.errors import OperationFailure
@@ -36,14 +37,17 @@ from places_geocode.app.models import density_models, common_models, reverse_mod
 
 # cython modules import
 from ctypes import *
+
+path = os.path.dirname(os.path.realpath(__file__))
+
 try:
-    spreadsheet_c = cdll.LoadLibrary("places_geocode/app/CythonOperations/spreadsheet_c.cpython-38-darwin.so")
-    reverse_spreadsheet = cdll.LoadLibrary("places_geocode/app/CythonOperations/reverse_spreadsheet.cpython-38-darwin.so")
-    TFIDF_max = cdll.LoadLibrary("places_geocode/app/CythonOperations/TFIDF_max.cpython-38-darwin.so")
-    null_parameters = cdll.LoadLibrary("places_geocode/app/CythonOperations/null_parameters.cpython-38-darwin.so")
-    certainty_search = cdll.LoadLibrary("places_geocode/app/CythonOperations/certainty_search.cpython-38-darwin.so")
-    radius_arr = cdll.LoadLibrary("places_geocode/app/CythonOperations/radius_arr.cpython-38-darwin.so")
-    TFIDF_max_elastic = cdll.LoadLibrary("places_geocode/app/CythonOperations/TFIDF_max_elastic.cpython-38-darwin.so")
+    spreadsheet_c = CDLL("{}/spreadsheet_c.cpython-38-darwin.so".format(path))
+    reverse_spreadsheet = CDLL("{}/reverse_spreadsheet.cpython-38-darwin.so".format(path))
+    TFIDF_max = CDLL("{}/TFIDF_max.cpython-38-darwin.so".format(path))
+    null_parameters = CDLL("{}/null_parameters.cpython-38-darwin.so".format(path))
+    certainty_search = CDLL("{}/certainty_search.cpython-38-darwin.so".format(path))
+    radius_arr = CDLL("{}/radius_arr.cpython-38-darwin.so".format(path))
+    TFIDF_max_elastic = CDLL("{}/TFIDF_max_elastic.cpython-38-darwin.so".format(path))
 except:
     from places_geocode.app.CythonOperations import spreadsheet_c, reverse_spreadsheet, TFIDF_max, null_parameters, TFIDF_max_elastic, certainty_search, radius_arr
 
